summaryrefslogtreecommitdiff
path: root/cmake/CheckGit.cmake
diff options
context:
space:
mode:
authorDominick Allen <djallen@librehumanitas.org>2024-10-05 08:33:39 -0500
committerDominick Allen <djallen@librehumanitas.org>2024-10-05 08:33:39 -0500
commit79620980ea3880f6512a35b9d688a60a02ff8b98 (patch)
treeb4ab3dfc656b88989f3e4234e9c476c295c176ed /cmake/CheckGit.cmake
parentb50980ad70684530d55b7adf20de6047ebf53ba2 (diff)
Formatting changes. Refactoring out detail::CopyMove from Result.
Diffstat (limited to 'cmake/CheckGit.cmake')
-rw-r--r--cmake/CheckGit.cmake14
1 files changed, 7 insertions, 7 deletions
diff --git a/cmake/CheckGit.cmake b/cmake/CheckGit.cmake
index bd17447..f7d8bce 100644
--- a/cmake/CheckGit.cmake
+++ b/cmake/CheckGit.cmake
@@ -7,8 +7,8 @@ if (NOT DEFINED post_configure_dir)
set(post_configure_dir ${CMAKE_BINARY_DIR}/include)
endif ()
-set(pre_configure_file ${pre_configure_dir}/git_version.hpp.in)
-set(post_configure_file ${post_configure_dir}/git_version.hpp)
+set(pre_configure_file ${pre_configure_dir}/fud_version.hpp.in)
+set(post_configure_file ${post_configure_dir}/fud_version.hpp)
function(CheckGitWrite git_hash)
file(WRITE ${CMAKE_BINARY_DIR}/git-state.txt ${git_hash})
@@ -37,15 +37,15 @@ function(CheckGitVersion git_hash)
file(MAKE_DIRECTORY ${post_configure_dir})
endif ()
- # if (NOT EXISTS ${post_configure_dir}/git_version.h)
- # file(COPY ${pre_configure_dir}/git_version.h DESTINATION ${post_configure_dir})
+ # if (NOT EXISTS ${post_configure_dir}/fud_version.h)
+ # file(COPY ${pre_configure_dir}/fud_version.h DESTINATION ${post_configure_dir})
# endif()
if (NOT DEFINED GIT_HASH_CACHE)
set(GIT_HASH_CACHE "INVALID")
endif ()
# Only update the git_version.cpp if the hash has changed. This will
# prevent us from rebuilding the project more than we need to.
if (NOT ${GIT_HASH} STREQUAL ${GIT_HASH_CACHE} OR NOT EXISTS ${post_configure_file})
# Set che GIT_HASH_CACHE variable the next build won't have
@@ -70,8 +70,8 @@ function(CheckGitSetup top_git_hash)
BYPRODUCTS ${post_configure_file}
)
- add_library(git_version INTERFACE ${CMAKE_BINARY_DIR}/include/git_version.hpp)
- add_dependencies(git_version AlwaysCheckGit)
+ add_library(fud_version INTERFACE ${CMAKE_BINARY_DIR}/include/fud_version.hpp)
+ add_dependencies(fud_version AlwaysCheckGit)
CheckGitVersion(git_hash)
set(${top_git_hash} ${git_hash} PARENT_SCOPE)
@@ -37,15 +37,15 @@ function(CheckGitVersion git_hash)
set(GIT_HASH_CACHE "INVALID")
endif ()
- # Only update the git_version.cpp if the hash has changed. This will
+ # Only update the fud_version.cpp if the hash has changed. This will
# prevent us from rebuilding the project more than we need to.
if (NOT ${GIT_HASH} STREQUAL ${GIT_HASH_CACHE} OR NOT EXISTS ${post_configure_file})